@@ -211,6 +211,7 @@ def update_department(pk: int, data: dict):
         raise ValueError(f"{str(err)}  id: {pk}")
 
 
+@transaction.atomic
 def delete_department(organization_id: int, pk: int):
     """
     删除部门
@@ -288,6 +289,7 @@ def get_department_user(organization_id: int, department_id: int):
     # })
 
 
+@transaction.atomic
 def delete_department_user_map(organization_id: int, department_id: int, user_ids: list):
     """
     添加部门-用户的映射关系
@@ -307,3 +309,16 @@ def delete_department_user_map(organization_id: int, department_id: int, user_id
     ).delete()
 
     return Resp(data="移除成功")
+
+
+def mv_show_order(organization_id: int, data: dict):
+    """
+    修改部门show_order
+    :param organization_id:  组织id
+    :param data:  [{"id": 5, "show_order": 4}, {"id": 7, "show_order": 5}] --> [{"id": 5, "show_order": 5}, {"id": 7, "show_order": 4}]
+    :return:
+    """
+    for item in data:
+        Department.objects.filter(id=item["id"], organization_id=organization_id).update(show_order=item["show_order"])
+
+    return Resp()
