@@ -5,6 +5,8 @@
 @Time        : 2022/4/28 2:25 下午
 @Description :
 """
+from django.db import transaction
+
 from departments.common.config import ServerErrorCode, BadRequestCode
 from departments.utils.error_response import Resp
 from departments.utils.department_funcs import (
@@ -16,7 +18,8 @@ from departments.utils.department_funcs import (
     delete_department,
     add_department_user_map,
     get_department_user,
-    delete_department_user_map
+    delete_department_user_map,
+    mv_show_order
 )
 
 
@@ -64,12 +67,17 @@ class DepartmentViewSet(object):
     def delete(self, pk: int):
         return delete_department(self.organization_id, pk)
 
-    def move_show_order(self):
+    @transaction.atomic
+    def move_show_order(self, data: list):
         """
         移动顺序
+
+        :param data: [{"id": 1, "show_order": 0}, {"id": 2, "show_order": 1}]
         :return:
         """
-        pass
+        if len(data) > 2:
+            return Resp(code=BadRequestCode, msg="参数错误")
+        return mv_show_order(self.organization_id, data)
 
     # def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
     def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
